@@ -3,4 +3,4 @@
 /* { dg-do compile } */
 /* { dg-options "-std=iso9899:1999 -pedantic-errors" } */
 
-union u { int a; char b[]; }; /* { dg-error "error: flexible array member in union" } */
+union u { int a; char b[]; }; /* { dg-error "flexible array member in union" } */
