@@ -1,7 +1,7 @@
-#include <stdio.h>
 #include <stdlib.h>
-
+#include "m128-check.h"
 #include "cpuid.h"
+#include "sse-os-support.h"
 
 static void sse_test (void);
 
@@ -14,7 +14,7 @@ main ()
     return 0;
 
   /* Run SSE test only if host has SSE support.  */
-  if (edx & bit_SSE)
+  if ((edx & bit_SSE) && sse_os_support ())
     sse_test ();
 
   return 0;
